import codecs
from setuptools import setup, find_packages

setup(
    name='elasticachelock',
    version='0.0.1',
    description="Elasticache/Redis Lock for AWS Lambdas is a pure Python lib that implements a distributed locking mechanism using Redis Pub/Sub. It's designed for scenarios where multiple concurrent Lambda executions need to ensure that certain tasks are performed exclusively by a single instance. Supports configurable TTL, retry logic with backoff, customizable timeouts and timezone.",
    url='https://github.com/rabuchaim/elasticachelock',
    author='Ricardo Abuchaim',
    author_email='ricardoabuchaim@gmail.com',
    maintainer='Ricardo Abuchaim',
    maintainer_email='ricardoabuchaim@gmail.com',
    project_urls={
        "Issue Tracker": "https://github.com/rabuchaim/elasticachelock/issues",
        "Source code": "https://github.com/rabuchaim/elasticachelock"
    },    
    bugtrack_url='https://github.com/rabuchaim/elasticachelock/issues',    
    license='MIT',
    keywords=['aws','lambda','redis','lock','elasticache','distributed-locking','pub/sub','pubsub'],
    packages=find_packages(),
    py_modules=['elasticachelock', 'elasticachelock'],
    package_dir = {'elasticachelock': 'elasticachelock'},
    include_package_data=True,
    zip_safe = False,
    package_data={
        'elasticachelock': [
            'README.md',            
            '__init__.py', 
            'elasticachelock.py', 
        ],
    },
    python_requires=">=3.10",
    install_requires=[],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Topic :: Security',
        'Topic :: Internet',
        'Topic :: Internet :: Finger',
        'Topic :: Scientific/Engineering',
        'Topic :: System :: Monitoring',
        'Topic :: System :: Networking',
        'Topic :: System :: Systems Administration',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: Localization',
        'Topic :: Utilities',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'Intended Audience :: System Administrators',
        'Operating System :: MacOS',
        'Operating System :: Microsoft :: Windows :: Windows 10',
        'Operating System :: Microsoft :: Windows :: Windows 11',
        'Operating System :: Unix',
        'Operating System :: POSIX',
        'Operating System :: POSIX :: Linux',
        'Operating System :: POSIX :: BSD',
        'Operating System :: POSIX :: BSD :: FreeBSD',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.10',  
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
        'Programming Language :: Python :: Implementation :: PyPy',
        'License :: OSI Approved :: MIT License',
    ],
    long_description=codecs.open("README.md","r","utf-8").read(),
    long_description_content_type='text/markdown',
)
